moment_mph: Moments of the multivariate continuous phase-type distribution
Description
This function calculates the moments for the multivariate phase-type
distributions.
Usage
moment_mph(obj, v)
Value
A number representing the moment of a multivariate continuous phase-type distribution.
Arguments
obj
a mult_cont_phase_type.
v
a vector or an integer.
Details
The variables for which the moments are calculated can be specified in
the v vector as indices in the reward matrix of the
mult_cont_phase_type object.